Learn R Programming

dhsage (version 0.1.0)

Thailand: The data represent the number of women of reproductive age in Thailand

Description

The function provides the number of women of reproductive age 15-49 in Thailand based on the demographic health survey of 1987.

Usage

thai_1987

Value

sri_1987 gives gives the number of women of reproductive age 15-49 in Thailand.

Arguments

thai_1987

A vector of (non-negative) count values.

Author

Muhammad Imran

R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com.

Details

Based on the demographic health survey of 1987, the function gives the number of Thai women in the reproductive age range of 15 to 49.

References

Chayovan, Napaporn, Peerasit Kamnuansilpa,and John Knodel. 1988. Thailand Demographic and Health Survey 1987. Columbia, Maryland, USA: Institute of Population Studies/Thailand and Institute for Resource Development- IRD/Westinghouse.

See Also

sri_1987, heaping

Examples

Run this code
x <- thai_1987
# starting age 23 and ending age 62
heaping(x, 23, 62)
# starting age 15 and ending age 49
heaping(x, 15, 49)

Run the code above in your browser using DataLab