Whipple's indes can be computed by the following formula
$$WI=\left(\frac{P_{25}+P_{30}+P_{35}+\cdots\cdots+P_{60}}{P_{23}+P_{24}+P_{25}+\cdots\cdots+P_{62}}\right)\times500$$
where P represents the population of reported age in completed year. There are 5 categories for the index value, ranging from very rough to highly accurate. Data is classified as being very rough (if WI > 175), rough (125 < WI < 175), approximate (110 < WI < 125), accurate (105 < WI < 110) and highly accurate (WI < 105).
References
Yadav, A., Vishwakarma, M., and Chauhan, S. (2020). The quality of age data: Comparison between two recent Indian censuses 2001–2011. Clinical Epidemiology and Global Health, 8(2), 371-376.